@@ -2,10 +2,10 @@ from .index import init_rag_voice_bot, init_rag_voice_bot_async
 from .http.adapters import (
     use_in_fastapi,
     use_in_flask,
-    use_in_django,
-    use_in_starlette,
-    use_in_wsgi,
-    use_in_asgi
+    # use_in_django,
+    # use_in_starlette,
+    # # use_in_wsgi,
+    # # use_in_asgi
 )
 
 __all__ = ["init_rag_voice_bot", "init_rag_voice_bot_async"]
\ No newline at end of file
